summaryrefslogtreecommitdiff
path: root/src/mongo/db/views
diff options
context:
space:
mode:
authorHuayu Ouyang <huayu.ouyang@mongodb.com>2020-10-07 22:35:33 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-10-10 01:28:10 +0000
commit157bd022d420b7b4705c7c661bb02e1514824fb5 (patch)
treed5054086e5702ccccc83e78a2981a447dbb82309 /src/mongo/db/views
parent726c93eaf68f08e7ff46162268db9b11b1fcc934 (diff)
downloadmongo-157bd022d420b7b4705c7c661bb02e1514824fb5.tar.gz
SERVER-50421-2 Rename global server parameter validateFeaturesAsMaster to validateFeaturesAsPrimary
Diffstat (limited to 'src/mongo/db/views')
-rw-r--r--src/mongo/db/views/view_catalog.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/views/view_catalog.cpp b/src/mongo/db/views/view_catalog.cpp
index 2ed8ac9ee17..a6aae261dea 100644
--- a/src/mongo/db/views/view_catalog.cpp
+++ b/src/mongo/db/views/view_catalog.cpp
@@ -327,11 +327,11 @@ StatusWith<stdx::unordered_set<NamespaceString>> ViewCatalog::_validatePipeline(
boost::none);
// If the feature compatibility version is not kLatest, and we are validating features as
// master, ban the use of new agg features introduced in kLatest to prevent them from being
// persisted in the catalog.
// (Generic FCV reference): This FCV check should exist across LTS binary versions.
ServerGlobalParams::FeatureCompatibility::Version fcv;
- if (serverGlobalParams.validateFeaturesAsMaster.load() &&
+ if (serverGlobalParams.validateFeaturesAsPrimary.load() &&
serverGlobalParams.featureCompatibility.isLessThan(
ServerGlobalParams::FeatureCompatibility::kLatest, &fcv)) {
expCtx->maxFeatureCompatibilityVersion = fcv;
@@ -327,11 +327,11 @@ StatusWith<stdx::unordered_set<NamespaceString>> ViewCatalog::_validatePipeline(
boost::none);
// If the feature compatibility version is not kLatest, and we are validating features as
- // master, ban the use of new agg features introduced in kLatest to prevent them from being
+ // primary, ban the use of new agg features introduced in kLatest to prevent them from being
// persisted in the catalog.
// (Generic FCV reference): This FCV check should exist across LTS binary versions.